Error handler module - Error handling strategies and implementations
This module provides the ErrorHandler trait and DefaultErrorHandler implementation, error handling strategies, logging and reporting decisions.
Structs
- Default
Error Handler - Default error handler implementation
- Selective
Error Handler - Selective error handler that only handles certain types of errors
- Silent
Error Handler - Silent error handler that doesn’t log or report errors
- Verbose
Error Handler - Verbose error handler that logs and reports all errors
Traits
- Error
Handler - Error handler trait for custom error handling