Module handler

Module handler 

Error handler module - Error handling strategies and implementations

This module provides the ErrorHandler trait and DefaultErrorHandler implementation, error handling strategies, logging and reporting decisions.

Structs

DefaultErrorHandler
Default error handler implementation
SelectiveErrorHandler
Selective error handler that only handles certain types of errors
SilentErrorHandler
Silent error handler that doesn’t log or report errors
VerboseErrorHandler
Verbose error handler that logs and reports all errors

Traits

ErrorHandler
Error handler trait for custom error handling